@@ -10,6 +10,7 @@ from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC
 import getpass
 import json
 import keyring
+import ladok3.kth
 import os
 import pickle
 import re
@@ -18,12 +19,12 @@ import traceback
 
 import ladok3.data
 import ladok3.report
+import ladok3.student
 
 dirs = appdirs.AppDirs("ladok", "dbosk@kth.se")
 
 def err(rc, msg):
   print(f"{sys.argv[0]}: error: {msg}", file=sys.stderr)
-  traceback.print_exc(file=sys.stderr)
   sys.exit(rc)
 
 def warn(msg):
@@ -169,12 +170,13 @@ def main():
   cache_clear.set_defaults(func=clear_cache)
   ladok3.data.add_command_options(subp)
   ladok3.report.add_command_options(subp)
+  ladok3.student.add_command_options(subp)
   argcomplete.autocomplete(argp)
   args = argp.parse_args()
   LADOK_USER, LADOK_PASS = load_credentials(args.config_file)
   ls = restore_ladok_session([LADOK_USER, LADOK_PASS])
   if not ls:
-    ls = ladok3.LadokSessionKTH(LADOK_USER, LADOK_PASS)
+    ls = ladok3.kth.LadokSession(LADOK_USER, LADOK_PASS)
   if "func" in args:
     args.func(ls, args)
   store_ladok_session(ls, [LADOK_USER, LADOK_PASS])
